@@ -1,5 +1,7 @@
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from plone.app.layout.viewlets.common import ViewletBase
+from AccessControl import getSecurityManager
+from zope.component import getMultiAdapter
 
 # Sample code for a basic viewlet (In order to use it, you'll have to):
 # - Un-comment the following useable piece of code (viewlet python class).
@@ -18,4 +20,17 @@ class Sidebar(ViewletBase):
     render = ViewPageTemplateFile('sidebar.pt')
 
     def update(self):
-        pass
+        ploneview = getMultiAdapter((self.context, self.request), name=u'plone')
+        context_state = getMultiAdapter((self.context, self.request),
+                                         name=u'plone_context_state')
+
+        self.portlet_assignable = context_state.portlet_assignable()
+        self.object_url = context_state.object_url()
+    
+    def available(self):
+        secman = getSecurityManager()
+        if not secman.checkPermission('Portlets: Manage portlets', self.context):
+            return False
+        else:
+            return True
+
